@@ -13,7 +13,18 @@
 # limitations under the License.
 
 """
-A modular python framework for Computer Vision Inference
+A modular Python framework for Computer Vision Inference.
 """
 
-__version__ = "v1.0.3"
+__version__ = "v1.1.1"
+
+import os
+import sys
+
+from peekingduck.utils.logger import LoggerSetup
+from peekingduck.utils.requirement_checker import RequirementChecker
+
+LoggerSetup()
+
+if "READTHEDOCS" not in os.environ:
+    sys.meta_path.insert(0, RequirementChecker())
